==> jc-1.4.0.tar.gz: gnu/xml/xpath/FalseFunction.h <==
// final class gnu.xml.xpath.FalseFunction

// class file dependencies
// @dep_class d90c61647700b7f6 gnu_xml_xpath_Expr
// @dep_class c4477bbea79f0364 gnu_xml_xpath_FalseFunction
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_xpath_Expr

#include "gnu/xml/xpath/Expr.h"

#ifndef _JC_gnu_xml_xpath_FalseFunction_H_
#define _JC_gnu_xml_xpath_FalseFunction_H_

// Forward structure declarations
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_FalseFunction$sub_refs	_jc_gnu_xml_xpath_FalseFunction$sub_refs;
typedef struct _jc_gnu_xml_xpath_FalseFunction$sub_nonrefs	_jc_gnu_xml_xpath_FalseFunction$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_FalseFunction$refs	_jc_gnu_xml_xpath_FalseFunction$refs;
typedef struct _jc_gnu_xml_xpath_FalseFunction$nonrefs	_jc_gnu_xml_xpath_FalseFunction$nonrefs;
typedef struct _jc_gnu_xml_xpath_FalseFunction$object	_jc_gnu_xml_xpath_FalseFunction$object;

typedef const struct _jc_gnu_xml_xpath_FalseFunction$vmethods	_jc_gnu_xml_xpath_FalseFunction$vmethods;
typedef const struct _jc_gnu_xml_xpath_FalseFunction$vtable	_jc_gnu_xml_xpath_FalseFunction$vtable;
typedef const struct _jc_gnu_xml_xpath_FalseFunction$vtype	_jc_gnu_xml_xpath_FalseFunction$vtype;

// Constructors
extern void _jc_gnu_xml_xpath_FalseFunction$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_FalseFunction$object *);

// Virtual methods
extern struct _jc_gnu_xml_xpath_Expr$object *_jc_gnu_xml_xpath_FalseFunction$method$clone$8aac957948447f2f(_jc_env *, struct _jc_gnu_xml_xpath_FalseFunction$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_xpath_FalseFunction$method$evaluate$8764614230b47559(_jc_env *, struct _jc_gnu_xml_xpath_FalseFunction$object *, struct _jc_object *, jint, jint);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_xpath_FalseFunction$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_xpath_FalseFunction$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_xpath_FalseFunction$method_info$clone$8aac957948447f2f;
extern _jc_method _jc_gnu_xml_xpath_FalseFunction$method_info$evaluate$8764614230b47559;
extern _jc_method _jc_gnu_xml_xpath_FalseFunction$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_xpath_FalseFunction$vmethods {
	struct _jc_gnu_xml_xpath_Expr$object	*(*clone$8aac957948447f2f)(_jc_env *, struct _jc_gnu_xml_xpath_FalseFunction$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*evaluate$8764614230b47559)(_jc_env *, struct _jc_gnu_xml_xpath_FalseFunction$object *, struct _jc_object *, jint, jint);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_xpath_FalseFunction$object *);
};

// Vtable
struct _jc_gnu_xml_xpath_FalseFunction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_Expr$vmethods	gnu_xml_xpath_Expr;
	_jc_gnu_xml_xpath_FalseFunction$vmethods	gnu_xml_xpath_FalseFunction;
};

// Vtype
struct _jc_gnu_xml_xpath_FalseFunction$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_FalseFunction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_FalseFunction$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_FalseFunction$refs {
    _jc_gnu_xml_xpath_FalseFunction$sub_refs	gnu_xml_xpath_FalseFunction;
    _jc_gnu_xml_xpath_Expr$sub_refs	gnu_xml_xpath_Expr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_FalseFunction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_FalseFunction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_Expr$sub_nonrefs	gnu_xml_xpath_Expr;
    _jc_gnu_xml_xpath_FalseFunction$sub_nonrefs	gnu_xml_xpath_FalseFunction;
};

// Object instance structure
struct _jc_gnu_xml_xpath_FalseFunction$object {
	_jc_gnu_xml_xpath_FalseFunction$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_FalseFunction$vtype	*vtype;
	_jc_gnu_xml_xpath_FalseFunction$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_FalseFunction$vtype _jc_gnu_xml_xpath_FalseFunction$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_FalseFunction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_FalseFunction$class_object;

#endif	/* _JC_gnu_xml_xpath_FalseFunction_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/xpath/FalseFunction.h <==
// final class gnu.xml.xpath.FalseFunction

// class file dependencies
// @dep_class d90c61647700b7f6 gnu_xml_xpath_Expr
// @dep_class c4477bbea79f0364 gnu_xml_xpath_FalseFunction
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_xpath_Expr

#include "gnu/xml/xpath/Expr.h"

#ifndef _JC_gnu_xml_xpath_FalseFunction_H_
#define _JC_gnu_xml_xpath_FalseFunction_H_

// Forward structure declarations
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_FalseFunction$sub_refs	_jc_gnu_xml_xpath_FalseFunction$sub_refs;
typedef struct _jc_gnu_xml_xpath_FalseFunction$sub_nonrefs	_jc_gnu_xml_xpath_FalseFunction$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_FalseFunction$refs	_jc_gnu_xml_xpath_FalseFunction$refs;
typedef struct _jc_gnu_xml_xpath_FalseFunction$nonrefs	_jc_gnu_xml_xpath_FalseFunction$nonrefs;
typedef struct _jc_gnu_xml_xpath_FalseFunction$object	_jc_gnu_xml_xpath_FalseFunction$object;

typedef const struct _jc_gnu_xml_xpath_FalseFunction$vmethods	_jc_gnu_xml_xpath_FalseFunction$vmethods;
typedef const struct _jc_gnu_xml_xpath_FalseFunction$vtable	_jc_gnu_xml_xpath_FalseFunction$vtable;
typedef const struct _jc_gnu_xml_xpath_FalseFunction$vtype	_jc_gnu_xml_xpath_FalseFunction$vtype;

// Constructors
extern void _jc_gnu_xml_xpath_FalseFunction$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_FalseFunction$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_xml_xpath_Expr$object *_jc_gnu_xml_xpath_FalseFunction$method$clone$8aac957948447f2f(_jc_env *, struct _jc_gnu_xml_xpath_FalseFunction$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_xpath_FalseFunction$method$evaluate$8764614230b47559(_jc_env *, struct _jc_gnu_xml_xpath_FalseFunction$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_xpath_FalseFunction$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_xpath_FalseFunction$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_xpath_FalseFunction$method_info$clone$8aac957948447f2f;
extern _jc_method _jc_gnu_xml_xpath_FalseFunction$method_info$evaluate$8764614230b47559;
extern _jc_method _jc_gnu_xml_xpath_FalseFunction$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_xpath_FalseFunction$vmethods {
	struct _jc_gnu_xml_xpath_Expr$object	*(*clone$8aac957948447f2f)(_jc_env *, struct _jc_gnu_xml_xpath_FalseFunction$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*evaluate$8764614230b47559)(_jc_env *, struct _jc_gnu_xml_xpath_FalseFunction$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_xpath_FalseFunction$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_xpath_FalseFunction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_Expr$vmethods	gnu_xml_xpath_Expr;
	_jc_gnu_xml_xpath_FalseFunction$vmethods	gnu_xml_xpath_FalseFunction;
};

// Vtype
struct _jc_gnu_xml_xpath_FalseFunction$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_FalseFunction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_FalseFunction$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_FalseFunction$refs {
    _jc_gnu_xml_xpath_FalseFunction$sub_refs	gnu_xml_xpath_FalseFunction;
    _jc_gnu_xml_xpath_Expr$sub_refs	gnu_xml_xpath_Expr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_FalseFunction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_FalseFunction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_Expr$sub_nonrefs	gnu_xml_xpath_Expr;
    _jc_gnu_xml_xpath_FalseFunction$sub_nonrefs	gnu_xml_xpath_FalseFunction;
};

// Object instance structure
struct _jc_gnu_xml_xpath_FalseFunction$object {
	_jc_gnu_xml_xpath_FalseFunction$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_FalseFunction$vtype	*vtype;
	_jc_gnu_xml_xpath_FalseFunction$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_FalseFunction$vtype _jc_gnu_xml_xpath_FalseFunction$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_FalseFunction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_FalseFunction$class_object;

#endif	/* _JC_gnu_xml_xpath_FalseFunction_H_ */
